api.documents.v1.folder package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.folder package

## Submodules

## api.documents.v1.folder.folder_root module

Autogenerated API

`api.documents.v1.folder.folder_root.` `add_document`(folderID: int, name: str = None, data: str = None, text: str = None, mimeType: str = None, accessMode: str = 'roleBased', lockRequestTime: int = 300000, inheritExplicitPermissions: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a new document (PUBLIC) In order to create plain text document, use ‘text’ property and send text. Otherwise use ‘data’ property populated with base64 encoded representation of the document. Sending the both parameters will result in error.

  Return type: | `dict`

`api.documents.v1.folder.folder_root.` `add_folder`(parentID: int, name: str = None, accessMode: str = 'roleBased', inheritExplicitPermissions: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a new subfolder (PUBLIC)

  Return type: | `dict`
  Parameters: | parentID (int) – ID of parent folder name (str) – Name of new folder => Sanitize by regex [a-zA-Z0-9ÅåØøÆæ_-. ]* accessMode (str) – General access mode of new folder (default roleBased) inheritExplicitPermissions (bool) – Inherit explicit permissions from parent folder (default true)
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ParentFolderNotFoundException – on 404
  Returns: | {“offset”: 590, “limit”: 891, “responseCode”: 200, “count”: 541, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Ago happy animal.”, “messageTemplate”: “Work seem loss weight available public.”, “field”: “Sell produce agree state scene.”, “parameter”: {}, “timestamp”: 113938444}], “currentPage”: 96, “size”: 861}

`api.documents.v1.folder.folder_root.` `browse_folder`(folderID: int, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specified folder entries (PUBLIC)

  Return type: | `dict`
  Parameters: | folderID (int) – ID of folder to browse limit (int) – Maximum number of returned results offset (int) – Skip a number of results
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 FolderNotFoundException – on 404
  Returns: | {“offset”: 351, “limit”: 448, “responseCode”: 200, “count”: 241, “data”: [{“lastUpdatedTimestamp”: 1048170734, “createdByUser”: {“id”: 494, “customerID”: 557, “userName”: “taramoore”, “name”: “James Jackson”}, “createdTimestamp”: 436453650, “lastUpdatedByUser”: {“id”: 130, “customerID”: 850, “userName”: “edwardserrano”, “name”: “Molly Williams”}, “ownedByUser”: {“id”: 598, “customerID”: 321, “userName”: “linda62”, “name”: “Lauren Lee”}, “accessMode”: “writeRestricted”, “parentElements”: [{“id”: 711, “name”: “Andrew Olson”}], “effectiveAccessMode”: “writeRestricted”, “currentUserAccessLevel”: “read”, “elementType”: “document”, “name”: “Jonathan Jimenez”, “id”: 267}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Three choose drop cell clearly professional back really.”, “messageTemplate”: “Painting project along force open sign woman.”, “field”: “Opportunity statement vote thank than pull sure.”, “parameter”: {}, “timestamp”: 210084756}], “currentPage”: 596, “size”: 660}

`api.documents.v1.folder.folder_root.` `delete_folder`(folderID: int, cascadeDocumentID: list = None, mode: str = 'DELETE_IF_EMPTY', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete specified folder, possibly recursively discarding contained documents (PUBLIC) If folder contains undeleted documents, the mode must be DELETE_CASCADE_ALL or DELETE_CASCADE_LISTED_DOCUMENTS with a list of documents to delete. If mode is DELETE_IF_EMPTY (default) and folder contains undeleted documents, the request will fail with a 409 CONFLICT and a metadata key ‘documentID’ listing documents which are not deleted.

  Return type: | `dict`

`api.documents.v1.folder.folder_root.` `get_current_user_root_folder`(limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch root folder for the customers that current user has access to (PUBLIC) If the current user has access to a single customer it returns the content of that customer’s root folder, otherwise it returns the list of root folders for each customer, without a content.

  Return type: | `dict`

`api.documents.v1.folder.folder_root.` `get_folder_meta_info_by_id`(folderID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specified folder metadata (PUBLIC)

  Return type: | `dict`
  Parameters: | folderID (int) – ID of folder to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 935, “limit”: 191, “responseCode”: 200, “count”: 729, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Money parent likely especially enjoy plant close.”, “messageTemplate”: “Any financial meet continue.”, “field”: “Seven scientist employee.”, “parameter”: {}, “timestamp”: 871381829}], “currentPage”: 700, “size”: 342}

`api.documents.v1.folder.folder_root.` `grant_folder_access`(folderID: int, subjectID: int = None, level: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Grant access to specified folder (PUBLIC) If the access level is folder, the user is allowed to obtain the information about the folder (without folder content). If the access level is read, the user is allowed to obtain the content of the folder. If the access level is write, the user is allowed to update the folder.

  Return type: | `dict`

`api.documents.v1.folder.folder_root.` `list_folder_access`(folderID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch ACL for specified folder (PUBLIC)

  Return type: | `dict`
  Parameters: | folderID (int) – Folder ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 835, “limit”: 15, “responseCode”: 200, “count”: 909, “data”: [{“id”: 314, “subject”: {“id”: 979, “customerID”: 525, “name”: “Angela Walter”}, “level”: “folder”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Laugh reality page risk occur same.”, “messageTemplate”: “See stuff city production coach.”, “field”: “Community send region wife one it firm.”, “parameter”: {}, “timestamp”: 462542891}], “currentPage”: 352, “size”: 268}

`api.documents.v1.folder.folder_root.` `revoke_folder_access`(folderID: int, accessID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Revoke specified explicit access from folder (PUBLIC)

  Return type: | `dict`
  Parameters: | folderID (int) – Folder ID accessID (int) – Access ID
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 737, “limit”: 870, “responseCode”: 200, “count”: 729, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Gas save begin time get.”, “messageTemplate”: “Hit sometimes laugh smile.”, “field”: “Half three itself record hair focus life.”, “parameter”: {}, “timestamp”: 178112672}], “currentPage”: 570, “size”: 74}

`api.documents.v1.folder.folder_root.` `update_document_access_settings`(folderID: int, accessMode: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Change access settings on specified folder (PUBLIC) If the access mode is roleBased, user accessing the folder must have appropriate role, set by administrator. If the access mode is writeRestricted, user accessing the folder can read, but must have appropriate role for write, set by administrator. If the access mode is readRestricted, user accessing the folder must have appropriate roles for both read and write, set by administrator. If the access mode is explicit, user accessing the folder must have explicit grant by folder’s owner.

  Return type: | `dict`

`api.documents.v1.folder.folder_root.` `update_folder`(folderID: int, name: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update specified folder (PUBLIC)

  Return type: | `dict`
  Parameters: | folderID (int) – ID of folder to update name (str) – If set change folder name => Sanitize by regex [a-zA-Z0-9ÅåØøÆæ_-. ]*
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 111, “limit”: 451, “responseCode”: 200, “count”: 831, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “More personal of skill.”, “messageTemplate”: “Sing direction position project morning.”, “field”: “Compare box already hair get maybe involve.”, “parameter”: {}, “timestamp”: 854976512}], “currentPage”: 835, “size”: 118}

## Module contents